==> dtkwidget-5.6.2.2-2-x86_64.pkg.tar.zst: usr/lib/cmake/DtkWidget/DtkWidgetConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DtkWidgetConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/DtkWidget" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(DtkWidget_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/libdtk-5.6.2/DWidget")
set_and_check(DtkWidget_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
set(DtkWidget_TOOL_DIRS "${PACKAGE_PREFIX_DIR}/lib/libdtk-5.6.2/DWidget/bin")

include(CMakeFindDependencyMacro)
find_dependency(Dtk REQUIRED Core Gui)
set(DtkWidget_LIBRARIES dtkwidget ${DtkCore_LIBRARIES} ${DtkGui_LIBRARIES})

include_directories("${DtkWidget_INCLUDE_DIRS}")

check_required_components(DtkWidget)

# Keep deprecated variables for compatibility
set(DTKWIDGET_INCLUDE_DIR ${DtkWidget_INCLUDE_DIRS})
set(DTKWIDGET_TOOL_DIR ${DtkWidget_TOOL_DIRS})

==> dtkwidget-5.6.3-2-x86_64.pkg.tar.zst: usr/lib/cmake/DtkWidget/DtkWidgetConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DtkWidgetConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/DtkWidget" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(DtkWidget_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/libdtk-5.6.2/DWidget")
set_and_check(DtkWidget_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
set(DtkWidget_TOOL_DIRS "${PACKAGE_PREFIX_DIR}/lib/libdtk-5.6.2/DWidget/bin")

include(CMakeFindDependencyMacro)
find_dependency(Dtk REQUIRED Core Gui)
find_library(DtkWidget_LIBRARIES dtkwidget ${DtkWidget_LIBRARY_DIRS})
set(DtkWidget_LIBRARIES ${DtkWidget_LIBRARIES} ${DtkCore_LIBRARIES} ${DtkGui_LIBRARIES})

include_directories("${DtkWidget_INCLUDE_DIRS}")

check_required_components(DtkWidget)

# Keep deprecated variables for compatibility
set(DTKWIDGET_INCLUDE_DIR ${DtkWidget_INCLUDE_DIRS})
set(DTKWIDGET_TOOL_DIR ${DtkWidget_TOOL_DIRS})
